# Copyright (c) 2016, Camptocamp SA
# All rights reserved.

# Auto-generated file. Do not Edit!
INFO = {
    "git_hash": "07b497ff7e87f80966b571950a01fa74302217c9",
    "version": "2.0",
    "git_tag": "2.0.0.dev11",
}
